.. _porting_guides:

**********************
Ansible Porting Guides
**********************

This section lists porting guides that can help you in updating playbooks, plugins and other parts of your Ansible infrastructure from one version of Ansible to the next.

Please note that this is not a complete list. If you believe any extra information would be useful in these pages, you can edit by clicking `Edit on GitHub` on the top right, or raising an issue.

.. toctree::
   :maxdepth: 2
  
   porting_guide_2.0
   porting_guide_2.3
   porting_guide_2.4
   porting_guide_2.5
   porting_guide_2.6
